#!/bin/sh

#
# cleanblendac.sh script cleaner from blender export ac file
# to torcs ac file (ac3d).
# by Michel Luc cern91@tuxfamily.org
#

name=tuxland
category=road

oldir=`pwd`

# Check cmd line param
if [ $# -lt 2 ]
  then 
        echo -e "\E[33;33m\033[1m* $usage \033[0m";
	echo "Usage =>  $0 track_Name category_Name :"
	echo -e "\E[32;32m\033[1m       $0 $name $category \033[0m";
	echo .
  else
    name=$1
    category=$2
fi

# check tracks directory
if [ -d $TORCS_BASE ]
	then
	 # Build in Torcs sources directory
	 # you need Makefile and run make install from this track directory.
	torcsdir=${TORCS_BASE}/data/tracks/${category}/$name
	else
	# Build in Torcs installation directory
	torcsdir=/usr/local/share/games/torcs/tracks/${category}/$name
fi

if [ ! -d $torcsdir ]
	then
	trackdir=${oldir}
	else
	trackdir=${torcsdir}
fi


## Messages ##

 lng=`echo $LANG | grep fr`
 if [ -z $lng ]
	then
		lng='EN'
	else
		lng='FR'
fi
if [ "$lng" = "FR" ]
	then
	msg1="Erreur : Aucun rpertoire $trackdir\n Editez ce script $0 et modifier le chemin \
	du rpertoire de Torcs si ncessaire !"
	msg2="Nettoyage de la piste $name.ac"
	msg3="Vous devez crer la carte d'lvation, elevation-map.png, à partir de la carte \
	gnre $name-elv.png"
	msg4="Erreur : La carte shadow2.rgb n'existe pas !\n Vous devez crer cette carte, \
	des ombres, pour gnrer votre fichier $name.acc (piste+ombres)."
	msg5="Utilisez cette image $name-elv2.png dans GIMP pour construire la carte elevation-map.png"
	msg6="Vous devez editer $name.xml et changer $name.ac en $name.acc"
fi
if [ "$lng" = "EN" ]
	then
	msg1="Error: $trackdir doesnt exist\n Check your $name directory or edit this $0 script \ 		and change the Torcs PATH if needed !"
	msg2="Cleaning the main track: $name.ac"
	msg3="You need this elevation-map.png image, create that from the $name-elv.png"
	msg4="Error: shadow2.rgb doesnt exist !\n You can create this shadow image \
	to have a new $name.acc file (track+shadow)."
	msg5="Use this $name-elv2.png in GIMP to build the elevation-map."
	msg6="Now edit the $name.xml file and replace $name.ac with $name.acc"
fi

##==========##
clear
echo " ==================================================="
echo "  Cleaning the $name Blender export ac file"
echo " ==================================================="
echo ""

if [ -d $trackdir ]
	then
		cd $trackdir
	else
		echo $msg1
		exit 1
fi

# Generate main track ac file
if [ -e $name.ac ]
	then
                echo $msg2
		if [ -e $name-bak.ac ]
		    then
		    rm -f $name-bak.ac
		echo""
		    echo "old $name-bak.ac file deleted"
		fi
		echo "*** Removing crease lines ***"
		sed '/crease/d' $name.ac > $name-bak.ac && mv $name-bak.ac $name.ac
		echo ""
	else
		echo "Aborted: $name.ac doesnt exist!!!"
		echo ""
		exit 1
fi

	echo "Remove the Mesh lines ? (N/y)?  "
	read rmmesh
	case $rmmesh in
		[YyoO]*)
		echo "*** Removing Mesh lines ***"
		sed '/Mesh/d' $name.ac > $name-bak.ac && mv $name-bak.ac $name.ac
		echo ""
		;;
		*)
			echo "WARNING: Mesh lines NOT deleted!"
			echo "You Can't use this ac file to build the accc file!"
			echo ""
		;;
	esac


echo " ========================================"
echo "        Now create the acc file"
echo " ========================================"
echo ""
	echo "To be continued (N/y)?  "
	read genac
	case $genac in
		[YyoO]*)
			echo "Yes: OK!"
		;;
		*)
			echo "bye!"
			exit 1
		;;
	esac


# elevation Map
if [ -e "elevation-map.png" ]
	then
		echo "elevation-map.png OK!"
		count="OK"
	else
		echo "*** Elevation Map ***"
		echo "WARNING: elevetion-map.png doesnt exit!"
		echo $msg3
		echo "Create the $name-elv2.png to build your elevation-map?"
		echo "To be continued (N/y)?  "
	read genelv
	case $genelv in
		[YyoO]*)
			echo "Yes: OK!"
		;;
		*)
			echo "bye!"
			exit 1
		;;
	esac

		#echo "Generate $name-elv, $name-elv1, $name-elv2 and $name-elv3"
		echo "Generate $name-elv2 "
		#trackgen -n $name -c $category -E 0
		trackgen -E 2 -n $name -c $category
		echo $msg5
fi


# shadows Env
echo ""
echo "*** Env Shadow ***"

if [ -z $count ]
	then
	echo ""
	echo "NO elevation-map image in $name track directory!"
	 echo "To be continued (N/y)?  "
	read genshad
	case $genshad in
		[YyoO]*)
			echo "Yes: OK!"
		;;
		*)
			echo "bye!"
			exit 1
		;;
	esac
fi

if [ ! -e "${name}-bak.ac" ]
	then
	cp $name.ac ${name}-bak.ac
fi


		if [ -e $name-shade.ac ]
		    then
		    rm -f $name-shade.ac
		echo""
		    echo "old $name-shade.ac file deleted"
		fi

if [ -e "shadow2.rgb" ]
	then
    echo " shadow2.rgb OK!"
	echo "Create $name-shade.ac file"
	accc +shad $name-bak.ac $name-shade.ac
	else
		echo $msg4
		exit 1
fi

if [ ! -e "$name-shade.ac" ]
	then
	accc +shad $name.ac $name-shade.ac
fi

if [ -e "$name-shade.ac" ]
	then
	echo "$name-shade.ac file OK!"
	echo "Combine the main track with envshadow in $name.acc file"
accc -g $name.acc -l0 $name-bak.ac -l1 $name-shade.ac -d3 1000 -d2 500 -d1 300 -S 300 -es
	else
	echo "Error: $name-shade.ac doesnt exist!!!"
	 exit 1
fi

echo ""
echo "All done!"
echo ""
echo "==================================================================="
echo $msg6
echo "==================================================================="
echo ""
cd $oldir
exit 0


