#!/bin/bash

# generate.sh is a shell script to build
# the ac and acc files of your tracks for Torcs 1.3.
#
# License : GPL
# CopyLeft: MLuc 2006-07-21 : LnX-cern91- 
# email   : mluc@cern91.net
# download: ftp://download.tuxfamily.org/debux/Torcs/
#

## You can set the values of name and category
name=tuxland
category=road

oldir=`pwd`

##**************************************************

## Maybe you need to set the TORCS_DIR variable
## Change and uncomment this 2 lines:
#TORCS_DIR=/usr/games/share/torcs
#export $TORCS_DIR

## or just modify your Torcs tracks path:
torcs_tracks_dir=/usr/local/share/games/torcs/tracks

##**************************************************


###### DON'T EDIT THE FOLLOW LINES #######

# check tracks directory

if [ -d $TORCS_DIR ]
	then
	torcsdir=${TORCS_DIR}/tracks
	else
	torcsdir=$torcs_tracks_dir
	tbv="no"
fi

if [ ! -d $torcsdir ]
	then
	trackdir=${oldir}
	else
	trackdir=${torcsdir}/${category}/$name
fi



## Messages ##

 lng=`echo $LANG | grep fr`
 if [ -z $lng ]
	then
		lng='EN'
	else
		lng='FR'
fi
if [ "$lng" = "FR" ]
	then
        usage="Vous pouvez utiliser ce script pour tous vos circuits :"
	err1=" Aucun rpertoire $trackdir !"
	err1b=" Editez ce script $0 et modifier le chemin \
	du rpertoire de Torcs si ncessaire !"
	err2=" La carte shadow2.rgb n'existe pas ! Vous devez crer cette carte, \
	des ombres, pour gnrer votre fichier $name.acc (piste+ombres)."
	msg2="Cration de la piste $name.ac"
	msg3="Vous devez crer la carte d'lvation, elevation-map.png, à partir de la carte \
	gnre $name-elv.png"
	msg4=" le fichier $name.ac existe dj !"
	msg4a="Voulez vous construire un nouveau fichier $name.ac ?(N/o)"
	msg4b=" Tapez o pour gnrer un nouveau fichier $name.ac"
	msg5="Vous devez editer $name.xml et changer $name.ac en $name.acc"
fi
if [ "$lng" = "EN" ]
	then
        usage="You can use this script on all yours tracks:"
	err1=" $trackdir doesnt exist!"
	err1b=" Check your $name directory or edit this $0 script \
 		and change the Torcs PATH if needed !"
	err2=" shadow2.rgb doesnt exist ! You can create this shadow image \
	to have a new $name.acc file (track+shadow)."
	msg2="Create the main track: $name.ac"
	msg3="You need this elevation-map.png image, create that from the $name-elv.png"
	msg4=" the $name.ac file allready exist!"
	msg4a="Generate a new $name.ac file? (N/y)"
	msg4b=" Type y to generate a new $name.ac file"
	msg5="Now edit the $name.xml file and replace $name.ac with $name.acc"
fi


### FUNCTIONS ###

ER_printf()
{
        echo -e "\033[01;31mWarning: No \$TORCS_DIR variable! Path set to $trackdir \033[0m";
}

NO_printf()
{
        echo -e '\033[01;31m No: aborted! \033[0m'
}
OK_printf()
{
        echo -e '\E[32;32m\033[1m Yes: Ok! \033[0m'
}
DONE_printf()
{
        echo -e '\E[36;36m\033[1m All Done \033[0m'
}


function buildtrack () {
	echo "  Generate the ac file ${trackdir}/$name.ac"
	trackgen -a -n $name -c $category
}

function buildblendac () {
echo " ==================================================="
echo "  Cleaning the $name Blender export ac file"
echo " ==================================================="
echo ""
if [ -e $name-bak.ac ]
    then
	rm -f $name-bak.ac
	echo""
	echo "old $name-bak.ac file deleted"
fi
echo "*** Removing crease 30 lines ***"
sed '/crease/d' $name.ac > $name-bak.ac && mv $name-bak.ac $name.ac
echo ""
if [ ! -e $name.ac ]
	then
		echo -e "\E[31;31m\033[1mError: $name.ac doesnt exist!!! \033[0m"
		echo ""
		exit 1
fi

echo -n "Remove the Mesh lines ? (N/y)?  "
read rmmesh
case $rmmesh in
	[YyoO])
		OK_printf
		echo "*** Removing Mesh lines ***"
		sed '/Mesh/d' $name.ac > $name-bak.ac && mv $name-bak.ac $name.ac
		echo ""
	;;
	*)
		NO_printf
		echo -e "\E[37;37m\033[1mWarning: Mesh lines NOT deleted! \033[0m"
		echo "If $name.ac file is a Blender export ac file"
		echo "You Can't use this ac file to build a correct acc file!"
		blendmesh="no"
		echo .
	;;
esac

if [ ! -z $blendmesh ]
   then
	echo -n "Continue ? (N/y)?  "
	read nomesh
	case $nomesh in
		[YyoO])
			OK_printf
			echo "*** Removing Mesh lines ***"
			sed '/Mesh/d' $name.ac > $name-bak.ac && mv $name-bak.ac $name.ac
			echo ""
		;;
		*)
			NO_printf
			echo "Bye!"
			exit 1
		;;
	esac
fi

buildtrack

}

function chkblendacfile () {
echo "If your $name.ac file is an Blender Export ac file, you need to clean this ac file."
echo -n "Do you want to clean this ac file? (N/y) "
	read ansblend
	case $ansblend in
		[YyoO])
			OK_printf
	        	buildblendac
		;;
		[Nn]*)
			NO_printf
			buildtrack
		;;
	esac
}

function buildelv0 () {
	echo "Generate $name-elv, $name-elv1, $name-elv2 and $name-elv3 in ${trackdir} directory "
	trackgen -n $name -c $category -E 0
}

function buildelv2 () {
	echo "  Generate the elevation file ${trackdir}/${name}-elv2.png "
	trackgen -n $name -c $category -E 2
}

function buildshad () {
	cp $name.ac ${name}-bak.ac
	echo "Create $name-shade.ac file"
	accc +shad $name-bak.ac $name-shade.ac >/dev/null || exit 1
	echo ""
	echo "Combine the main track with envshadow in $name.acc file"
accc -g $name.acc -l0 $name-bak.ac -l1 $name-shade.ac -d3 1000 -d2 500 -d1 300 -S 300 -es >/dev/null || exit 1
}


##===== START =====##
clear
echo "    *-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* "
echo -e '\E[36;36m\033[1m            TORCS Open Racing Cars \033[0m';
echo "    *-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* "
echo .
echo " generating the ac and acc files for Torcs 1.3++"
echo ""

# check $TORCS_DIR = Error
if [ ! -z $tbv ]
	then
		ER_printf
		echo ""
fi

# Check cmd line param
if [ $# -lt 2 ]
  then 
        echo -e "\E[33;33m\033[1m* $usage \033[0m";
	echo "Usage =>  $0 track_Name category_Name :"
	echo -e "\E[32;32m\033[1m       $0 $name $category \033[0m";
	echo .
  else
    name=$1
    category=$2
fi

# Create the ac file if exist or not
echo -e "\E[36;36m\033[1m   *** Generate Main Track at $name *** \033[0m";
echo ""

echo "  Generate the acc file ${trackdir}/$name.acc  "
echo "Do you want create this file?"
echo -n "Type n to Stop! "
read anstop 
	case $anstop in
		[Nn])
			NO_printf
			echo " bye!"
			exit 1
		;;
		[YyOo]*)
			OK_printf
		;;
	esac

echo ""

# Check Path to this track
if [ -d $trackdir ]
	then
		cd $trackdir
	else
		echo -e "\E[31;31m\033[1mError: $err1 \033[0m";
		echo -e "\E[31;31m\033[1m $err1b \033[0m";
		echo " bye! "
		exit 1
fi


# Create the ac file if exist or not
if [ ! -e $name.ac ]
	then
		echo -e '\E[36;36m\033[1m   *** Main Track *** \033[0m';
		echo $msg2
		buildtrack
	else
		echo -e "\E[37;37m\033[1mWarning:  $name.ac exist! \033[0m";
		echo $msg4
		acfile="1"
fi

if [ "$acfile" = "1" ]
    then
        echo $msg4a
        echo $msg4b
	read ansok
	case $ansok in
		[YyoO])
			OK_printf
	        	chkblendacfile
		;;
		[Nn]*)
			NO_printf
		;;
	esac
fi

echo ""

# Check if elevation-map file doesnt exist and  generate elevation track
if [ -e "elevation-map.png" ]
	then
		echo -e '\E[36;36m\033[1m elevation-map.png OK! \033[0m';
		count="OK"
	else
		echo -e '\E[36;36m\033[1m   *** Elevation Map *** \033[0m';
		#buildelv0
		buildelv2
		echo $msg3
fi

echo ""
echo -e '\E[36;36m\033[1m   *** Env Shadow *** \033[0m';

if [ -z $count ]
	then
	echo ""
	echo "NO elevation-map image in $name track directory!"
	 echo -n " continue (N/y)?  "
	read genshad
	case $genshad in
		[YyoO])
			OK_printf
		;;
		[Nn]*)
			NO_printf
			echo " bye!"
			exit 1
		;;
	esac
fi


# Check shadow2.rgb file and build the accc file
if [ -e "shadow2.rgb" ]
	then
		buildshad
	else
		echo ""
		echo -e "\E[31;31m\033[1mError: $err2 \033[0m";
		exit 1
fi

echo ""
DONE_printf
echo ""
echo "============================================================================"
echo -e "\E[33;33m\033[1m $msg5 \033[0m";
echo "============================================================================"
cd $oldir
exit 0


